@@ -4,8 +4,10 @@ from __future__ import absolute_import
 from attest import assert_hook, Assert, Tests
 import copy
 from django.core.paginator import Paginator
+from django.db.models.query import QuerySet
 from django.http import Http404
 import django_tables2 as tables
+from django_tables2.tables import DeclarativeColumnsMetaclass
 from haystack.query import SearchQuerySet
 
 
@@ -58,6 +60,38 @@ def declarations():
     assert 'added' in CityTable.base_columns
 
 
+@core.test
+def metaclass_inheritance():
+    class Tweaker(type):
+        """Adds an attribute "tweaked" to all classes"""
+        def __new__(cls, name, bases, attrs):
+            attrs['tweaked'] = True
+            return super(Tweaker, cls).__new__(cls, name, bases, attrs)
+
+    class Meta(Tweaker, DeclarativeColumnsMetaclass):
+        pass
+
+    class TweakedTable(tables.Table):
+        __metaclass__ = Meta
+        name = tables.Column()
+
+    table = TweakedTable([])
+    assert 'name' in table.columns
+    assert table.tweaked
+
+    # now flip the order
+    class FlippedMeta(DeclarativeColumnsMetaclass, Tweaker):
+        pass
+
+    class FlippedTweakedTable(tables.Table):
+        __metaclass__ = FlippedMeta
+        name = tables.Column()
+
+    table = FlippedTweakedTable([])
+    assert 'name' in table.columns
+    assert table.tweaked
+
+
 @core.test
 def attrs():
     class TestTable(tables.Table):
@@ -129,7 +163,14 @@ def sorting():
     assert SortedTable([], order_by='alpha').order_by   == ('alpha', )
     assert SortedTable([], order_by=('beta',)).order_by == ('beta', )
 
+    class NoOrderByQuerySet(QuerySet):
+        def order_by(self, *args, **kwargs):
+            raise NotImplementedError
+
     # "no sorting"
+    table = UnsortedTable(NoOrderByQuerySet())
+    assert table.order_by == None
+
     table = SortedTable([])
     table.order_by = []
     assert () == table.order_by == SortedTable([], order_by=[]).order_by
